@@ -98,3 +98,30 @@ test('Terminal should open in Launcher cwd', async ({ page, tmpPath }) => {
   await page.waitForTimeout(1000);
   expect(await terminal.screenshot()).toMatchSnapshot('launcher-term.png');
 });
+
+test('Terminal web link', async ({ page, tmpPath }) => {
+  await page.waitForSelector(`.jp-Launcher-cwd > h3:has-text("${tmpPath}")`);
+
+  await page.locator('[role="main"] >> p:has-text("Terminal")').click();
+
+  const terminal = page.locator(TERMINAL_SELECTOR);
+  await terminal.waitFor();
+
+  await page.waitForTimeout(1000);
+  await page.keyboard.type('echo https://jupyter.org/');
+  await page.keyboard.press('Enter');
+  await page.waitForTimeout(1000);
+  await Promise.all([
+    terminal.locator('.jp-Terminal-body.xterm-cursor-pointer').waitFor(),
+    terminal
+      .locator('canvas')
+      .last()
+      .hover({
+        position: {
+          x: 60,
+          y: 23
+        }
+      })
+  ]);
+  expect(await terminal.screenshot()).toMatchSnapshot('web-links-term.png');
+});
